==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/ChromeBrowserVersion.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Current version of the Chrome Browser
 */
@ApiModel(description = "Current version of the Chrome Browser")
@JsonPropertyOrder({ ChromeBrowserVersion.JSON_PROPERTY_MINIMUM })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class ChromeBrowserVersion implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_MINIMUM = "minimum";
    private String minimum;

    public ChromeBrowserVersion() {
    }

    public ChromeBrowserVersion minimum(String minimum) {

        this.minimum = minimum;
        return this;
    }

    /**
     * Get minimum
     *
     * @return minimum
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_MINIMUM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getMinimum() {
        return minimum;
    }

    @JsonProperty(JSON_PROPERTY_MINIMUM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setMinimum(String minimum) {
        this.minimum = minimum;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ChromeBrowserVersion chromeBrowserVersion = (ChromeBrowserVersion) o;
        return Objects.equals(this.minimum, chromeBrowserVersion.minimum);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(minimum);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ChromeBrowserVersion {\n");
        sb.append("    minimum: ").append(toIndentedString(minimum)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: com/okta/sdk/resource/model/ChromeBrowserVersion.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Current version of the Chrome Browser
 */
@ApiModel(description = "Current version of the Chrome Browser")
@JsonPropertyOrder({ ChromeBrowserVersion.JSON_PROPERTY_MINIMUM })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class ChromeBrowserVersion implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_MINIMUM = "minimum";
    private String minimum;

    public ChromeBrowserVersion() {
    }

    public ChromeBrowserVersion minimum(String minimum) {

        this.minimum = minimum;
        return this;
    }

    /**
     * Get minimum
     *
     * @return minimum
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_MINIMUM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getMinimum() {
        return minimum;
    }

    @JsonProperty(JSON_PROPERTY_MINIMUM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setMinimum(String minimum) {
        this.minimum = minimum;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ChromeBrowserVersion chromeBrowserVersion = (ChromeBrowserVersion) o;
        return Objects.equals(this.minimum, chromeBrowserVersion.minimum);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(minimum);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ChromeBrowserVersion {\n");
        sb.append("    minimum: ").append(toIndentedString(minimum)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
